@@ -80,6 +80,10 @@ public:
  	  * @param pFactory sets #_pFactory
 	  */
 	virtual bool init(IProvider* pProvider, IPluginFactory* pFactory);
+	/** @brief Default implementation for actions, returning an empty list. */
+	vector< pair<QString, QAction*> > actions() { return vector< pair<QString, QAction*> >(); };
+
+	
 	//@}
 	/** @name IXmlStorable interface
 	  * 
