@@ -82,8 +82,8 @@ class PackageDisplayWidget : public QTableWidget, public NPlugin::IPluginUser, p
 	  * The appropriate data will be applied a column when it is added.
 	  */
 	map<QString, Column> _loadedColumnSettings;
-	const static int CHAR_WIDTH;
-	const static int MARGIN;
+    int WIDGET_CHAR_WIDTH;
+    int MARGIN;
 
 public:
 	PackageDisplayWidget(QWidget * pParent = 0);
