@@ -101,7 +101,7 @@ template class LesserPriority<NPlugin::InformationPlugin>;
 template class LesserPriority<NPlugin::ShortInformationPlugin>;
 
 
-PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFlags fl )
+PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WindowFlags fl )
 : QMainWindow(parent, fl), _DETAILS_INFORMATION_PRIORITY(2), _network(NUtil::NetworkSettings::SYSTEM_PROXY)
 //_network(NUtil::NetworkSettings::ProxyType::SYSTEM_PROXY), no C++11 :(
 {
@@ -277,6 +277,10 @@ void PackageSearchImpl::initialize()
 	}
 	while (!success);
 
+    makeHandleVisible(_pHSplitter->handle(1));
+    makeHandleVisible(_pUpperVSplitter->handle(1));
+    makeHandleVisible(_pLowerVSplitter->handle(1));
+
 	// create the hard coded plugins
 	_pPackageNamePlugin = new NPlugin::PackageNamePlugin();
 	this->addPlugin(_pPackageNamePlugin);
@@ -1089,3 +1093,14 @@ void PackageSearchImpl::updateXapianDatabase()
 	setEnabled(true);
 }
 
+void PackageSearchImpl::makeHandleVisible(QSplitterHandle* pSplitterHandle) {
+    QVBoxLayout *layout = new QVBoxLayout(pSplitterHandle);
+    layout->setSpacing(0);
+    layout->setMargin(0);
+
+    QFrame *line = new QFrame(pSplitterHandle);
+    line->setFrameShape(QFrame::HLine);
+    line->setFrameShadow(QFrame::Sunken);
+    layout->addWidget(line);
+}
+
