@@ -15,12 +15,13 @@
 #include <cassert>
 
 #include <qapplication.h>
-#include <qdir.h>
+#include <QDir>
 #include <qstringlist.h>
 #include <QListWidget>
 #include <qlabel.h>
 #include <QMainWindow>
 #include <qstatusbar.h>
+#include <QTranslator>
 #include <QtDebug>
 
 #include <dlfcn.h>	// for dl*()
@@ -32,7 +33,6 @@
 #include "plugincontainer.h"
 #include "ipluginuser.h"
 #include "iprovider.h"
-#include "pluginsettingsdlg.h"
 #include "plugincontroldlgmeditator.h"
 
 // NXml
@@ -46,6 +46,9 @@
 namespace NPlugin 
 {
 
+
+
+
 PluginManager::PluginManager(vector<string> directories, IProvider* pProvider)
 	: _settingsVersion("0.2")
 {
@@ -205,10 +208,31 @@ PluginContainer* PluginManager::loadPlugin(
 	{
 		assert(libraryHandle != 0);
 		PluginData pluginData;
+		
 		// get the function for creating the plugin
 		NewPluginFkt func = NewPluginFkt(dlsym(libraryHandle, ("new_" + pluginName).c_str() ));
 		if (func != 0)	// if no error occured on load (i.e. the symbol was present)
 		{
+			// setup translation
+			QString locale = QLocale::system().name();
+			qDebug() << "Translation dir " << _translationDir.path();
+			QTranslator* pTranslator = new QTranslator();
+			if (pTranslator->load(_translationDir.filePath( toQString(pluginName) + "_" + locale))) 
+			{
+				qDebug() << "Loaded translation " << toQString(pluginName) + "_" + locale;
+				QApplication::installTranslator(pTranslator);
+				pluginData.pTranslator = pTranslator;
+			}
+			else 
+			{
+				delete pTranslator;
+				pTranslator = 0;
+				// warn if we have non-english and no translation
+				if (!locale.startsWith("en_"))
+					qWarning() << tr("No translation for plugin ") << toQString(pluginName) << 
+							tr(" found for current locale ") << locale;
+			}
+		
 			pPlugin = func();	// fetch the plugin
  			qDebug() << "Loaded plugin: " << pPlugin->title();
 			pluginData.directory = directory;
@@ -224,13 +248,20 @@ PluginContainer* PluginManager::loadPlugin(
 				if (pPlugin->init(_pProvider))	// if the container initializes successfully
 				{
 					pluginData.pPlugin = pPlugin;
+
+
+					
 					map<string, const QDomElement>::const_iterator it = _pluginSettings.find(pPlugin->name());
 					if ( it != _pluginSettings.end() )
 						pPlugin->loadSettings(it->second);
 					_plugins[pluginName] = pluginData;
+					
 				}
 				else
 				{
+					QApplication::removeTranslator(pluginData.pTranslator);
+					delete pluginData.pTranslator;
+					pluginData.pTranslator = 0;
 					delete pPlugin;
 					pPlugin = 0;
 				}
@@ -255,7 +286,10 @@ void PluginManager::unloadPlugin(PluginContainer* pPlugin)
 {
 	QString pluginTitle = pPlugin->title();
 	map<string, PluginData>::iterator it = _plugins.find(pPlugin->name());
-	assert(it->second.pPlugin != 0);
+	PluginData& pluginData = it->second;
+	assert(pluginData.pPlugin != 0);
+	delete pluginData.pTranslator;
+	pluginData.pTranslator = 0;
 	// add the settings of the plugin in _pluginSettings
 	{
 		NXml::XmlData data("SettingsDocument");
@@ -267,8 +301,8 @@ void PluginManager::unloadPlugin(PluginContainer* pPlugin)
 				make_pair(pPlugin->name(), data.root().firstChild().toElement()) );
 	}
 	delete pPlugin;
-	it->second.pPlugin = 0;
-	dlclose(it->second.libraryHandle);
+	pluginData.pPlugin = 0;
+	dlclose(pluginData.libraryHandle);
 	_pProvider->statusBar()->showMessage("Unloaded plugin " + pluginTitle, 3000);
 }
 
@@ -380,4 +414,9 @@ bool PluginManager::isLoaded(QString pluginName) const
 }
 
 
-};
+void PluginManager::setTranslationDir(const QDir& dir)
+{
+	_translationDir = dir;
+}
+
+}	// namespace NPlugin
