@@ -18,7 +18,9 @@
 #include <vector>
 
 #include <qdom.h>
+#include <QDir>
 #include <qobject.h>
+#include <QTranslator>
 
 // NXml
 #include <xmldata.h>
@@ -32,10 +34,12 @@
 
 using namespace std;
 
+class QDialog;
+class QDir;
 class QWidget;
 class QTableWidget;
+class QTranslator;
 class PluginProgressDlg;
-class QDialog;
 
 namespace NXml
 {
@@ -82,6 +86,8 @@ class PluginManager : public QObject, public PluginInformer, public NXml::IXmlSt
 private:
 	typedef vector<IPluginUser*> PluginUserContainer;
 	PluginUserContainer _users;
+	/** Stores the location were to search for translation file for the plugins. */
+	QDir _translationDir;
 protected:
 
 	/** @brief This holds information about the plugin. */
@@ -92,6 +98,7 @@ protected:
 		{
 			libraryHandle = 0;
 			pPlugin = 0;
+			pTranslator = 0;
 		}
 		PluginInformation information;
 		string directory;
@@ -108,6 +115,9 @@ protected:
 		
 		/** @brief A pointer to the instance of the plugin, 0 if the plugin is not loaded. */
 		PluginContainer* pPlugin;
+		
+		/** @brief The translator for the plugin (if any, otherwise 0). */
+		QTranslator* pTranslator;
 		/** @brief A handle of the loaded library for this plugin, 0 if the plugin is not loaded. */
 		void* libraryHandle;
 		/** @brief operator so it can be used in sets */
@@ -316,6 +326,9 @@ public:
 	virtual void addPlugin(Plugin* pPlugin);
 	virtual void removePlugin(Plugin* pPlugin);
 	//@}
+	
+	/** @brief Sets the directory were translations are stored. */
+	void setTranslationDir(const QDir& dir);
 
 };
 
