@@ -35,11 +35,6 @@
 #include "vocabularymodel.h"
 
 
-// Debug: Modeltest
-#ifdef __DEBUG
-#	include <modeltest.h>
-#endif
-
 #include <globals.h>
 
 #include "debtagssettingswidget.h"
@@ -134,10 +129,6 @@ bool DebtagsPluginContainer::init(IProvider* pProvider)
 	setDebtagsEnabled(true);
 
 	_pVocabularyModel = new NTagModel::VocabularyModel(this);
-
-#ifdef __DEBUG
-	new ModelTest(_pVocabularyModel, this);
-#endif
 	
 	// use dynamic cast here because of the virtual base class 
 	// (static_cast is not allowed there)
