@@ -15,6 +15,7 @@
 
 #include <QVariant>
 #include <QTimer>
+#include <QDebug>
 
 // NTagModel
 #include "vocabularymodel.h"
@@ -31,7 +32,7 @@ EmptyTagFilter::EmptyTagFilter(const VocabularyModel* pModel, const Xapian::Data
 {
 	_tagSelectionHasChanged = false;
 	_pVocabularyModel = pModel;
-	connect(_pVocabularyModel, SIGNAL(dataChanged(QModelIndex, QModelIndex)), SLOT(tagSelectionChanged()));
+	connect(_pVocabularyModel, SIGNAL(selectionChanged()), SLOT(tagSelectionChanged()));
 }
 
 
@@ -42,45 +43,37 @@ EmptyTagFilter::~EmptyTagFilter()
 
 bool EmptyTagFilter::filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const
 {
-	// TODO: Do not compute the companion tags every time the filterMethod is called, but only when the selected tags change
-
-	// tree filtering -> if a child is shown, also show the facet
 	QModelIndex current = sourceModel()->index(sourceRow, 0, sourceParent);
-	if (!current.isValid())
-	{
-		qDebug("[EmptyTagFilter::filterAcceptsRow] Invalid model index!");
-		return false;
-	}
-	for( int i = 0; i < sourceModel()->rowCount(current); ++i )
-	{
-		const QModelIndex child = current.child(i, 0);
-		if (filterAcceptsRow(i, current))
-			return true;
-	}
 
-	// facets without tags will not be shown
-	if (sourceModel()->data(current, TypeRole).toInt() == FacetTypeItem)
-		return false;
+	// facets are always accepted
+	if (sourceModel()->data(current, TypeRole).toInt() == FacetTypeItem) 
+	{
+		return true;
+	}
 	
 	// Also apply filtering if no tags are selected, because there are tags in the vocab
 	// which are not used
 	//if (_pVocabularyModel->selectedTags().empty())
 	//	return true;
 
+//	static set<string> companionTags;
+//	if (_tagSelectionHasChanged) {
+//		companionTags = ;
+//		_tagSelectionHasChanged = false;
+//	}
+//	if (companionTags.find(tag) == companionTags.end())
+//		qDebug("Tag " + toQString(tag.fullname()) + " is hidden as non-companion");
+//	else 
+//		qDebug("Tag " + toQString(tag.fullname()) + " is shown as companion");
+//	return companionTags.find(tag) != companionTags.end();
+
+	
 	Xapian::Enquire enq(_xapian);
 	set<Tag> includeTags = _pVocabularyModel->selectedTags();
  	Tag tag = sourceModel()->data(current, TagRole).value<TagWrapper>().tag;
 	includeTags.insert(tag);
 	
-	static set<string> companionTags;
-	if (_tagSelectionHasChanged) {
-		companionTags = _pVocabularyModel->selectedTags();
-		_tagSelectionHasChanged = false;
-	}
-
-	
-	
-	set<string> terms;		
+	set<string> terms;
 	for (set<Tag>::const_iterator it = includeTags.begin(); it != includeTags.end(); ++it)
 	{
 		terms.insert(string("XT") + *it);
@@ -89,39 +82,24 @@ bool EmptyTagFilter::filterAcceptsRow(int sourceRow, const QModelIndex& sourcePa
 	enq.set_query(query);
 	Xapian::MSet match = enq.get_mset(0, 1);
 	return (match.size() != 0);
-	return true;
- 	// if no tags are selected, the companion tags are useless -> show only those tags
- 	// which have a cardinality > 0
-// 	if (_pVocabularyModel->selectedTags().empty())
-// 		return _pVocabularyModel->debtags()->getCardinality(tag) > 0;
-/*	static set<Tag> companionTags;
-	if (_tagSelectionHasChanged) {
-		companionTags = _pVocabularyModel->debtags()->getCompanionTags(_pVocabularyModel->selectedTags());
-		_tagSelectionHasChanged = false;
-	}*/
-//	if (companionTags.find(tag) == companionTags.end())
-//		qDebug("Tag " + toQString(tag.fullname()) + " is hidden as non-companion");
-//	else 
-//		qDebug("Tag " + toQString(tag.fullname()) + " is shown as companion");
-// 	return companionTags.find(tag) != companionTags.end();
 }
 
 
 void EmptyTagFilter::tagSelectionChanged()
 {
 	_tagSelectionHasChanged = true;
-	// queue evaluation of tags
-// 	QTimer::singleShot(3000, this, SLOT(onSelectionChangedTimeout()));
-	invalidateFilter();
+	// it is not sufficient to call invalidateFilter() here (QT 4.5) this seems to be a QT bug
+	// calling only invalidateFilter() does lead to hidden facets not being displayed as expected
+/* Bug description:
+[LB] select tag biology:CLUSTAL/ALN, type XML into tag-filter, remove tag XML -> XML facets are no longer shown
+  Gives different result with biology:EMBOSSS
+  Same goes for: workswith::XML && use::Data Visualisation -> Filter: "compiler" -> remove use::Data vis (compiler should now show devel::compiler but does not)
+  */
+
+	invalidate();
 }
 
-void EmptyTagFilter::onSelectionChangedTimeout()
-{
-	invalidateFilter();
-}
 
 
 }	// NTagModel 
 
-#undef emit	
-#include <ept/debtags/debtags.tcc>
